@@ -16,9 +16,12 @@ struct LintRunnerConfig {
 struct LintConfig {
     name: String,
     include_patterns: Vec<String>,
-    exclude_patterns: Vec<String>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    exclude_patterns: Option<Vec<String>>,
     args: Vec<String>,
     init_args: Option<Vec<String>>,
+    #[serde(default)]
+    bypass_matched_file_filter: bool,
 }
 
 /// Given options specified by the user, return a list of linters to run.
@@ -31,7 +34,11 @@ pub fn get_linters_from_config(
     let mut linters = Vec::new();
     for lint_config in lint_runner_config.linters {
         let include_patterns = patterns_from_strs(&lint_config.include_patterns)?;
-        let exclude_patterns = patterns_from_strs(&lint_config.exclude_patterns)?;
+        let exclude_patterns = if let Some(exclude_patterns) = &lint_config.exclude_patterns {
+            patterns_from_strs(exclude_patterns)?
+        } else {
+            Vec::new()
+        };
         linters.push(Linter {
             name: lint_config.name,
             include_patterns,
@@ -39,6 +46,7 @@ pub fn get_linters_from_config(
             commands: lint_config.args,
             init_commands: lint_config.init_args,
             config_path: config_path.clone(),
+            bypass_matched_file_filter: lint_config.bypass_matched_file_filter,
         });
     }
     debug!(
