@@ -3,7 +3,7 @@ use console::style;
 use indicatif::{MultiProgress, ProgressBar};
 use lint_config::get_linters_from_config;
 use linter::Linter;
-use log::debug;
+use log::{debug, log_enabled};
 use path::AbsPath;
 use render::{print_error, render_lint_messages};
 use std::collections::HashMap;
@@ -134,7 +134,7 @@ fn get_changed_files() -> Result<Vec<AbsPath>> {
 }
 
 fn group_lints_by_file(
-    all_lints: &mut HashMap<AbsPath, Vec<LintMessage>>,
+    all_lints: &mut HashMap<Option<AbsPath>, Vec<LintMessage>>,
     lints: Vec<LintMessage>,
 ) {
     lints.into_iter().fold(all_lints, |acc, lint| {
@@ -145,10 +145,10 @@ fn group_lints_by_file(
     });
 }
 
-fn apply_patches(lint_messages: &HashMap<AbsPath, Vec<LintMessage>>) -> Result<()> {
+fn apply_patches(lint_messages: &HashMap<Option<AbsPath>, Vec<LintMessage>>) -> Result<()> {
     for (path, lint_messages) in lint_messages {
         for lint_message in lint_messages {
-            if let Some(replacement) = &lint_message.replacement {
+            if let (Some(replacement), Some(path)) = (&lint_message.replacement, path) {
                 std::fs::write(path.as_pathbuf(), replacement).context(format!(
                     "Failed to write apply patch to file: '{}'",
                     path.as_pathbuf().display()
@@ -235,31 +235,41 @@ fn do_lint(
 
     let mut thread_handles = Vec::new();
 
-    let spinners = MultiProgress::new();
+    let spinners = Arc::new(MultiProgress::new());
     for linter in linters {
-        let spinner = spinners.add(ProgressBar::new_spinner());
-        spinner.set_message(format!("{} running...", linter.name));
-        spinner.enable_steady_tick(100);
         let all_lints = Arc::clone(&all_lints);
         let files = Arc::clone(&files);
+        let spinners = Arc::clone(&spinners);
 
         let handle = thread::spawn(move || -> Result<()> {
+            let mut spinner = None;
+            if !log_enabled!(log::Level::Debug) {
+                let _spinner = spinners.add(ProgressBar::new_spinner());
+                _spinner.set_message(format!("{} running...", linter.name));
+                _spinner.enable_steady_tick(100);
+                spinner = Some(_spinner);
+            }
+
             let lints = linter.run(&files)?;
             let mut all_lints = all_lints.lock().unwrap();
             let is_success = lints.is_empty();
             group_lints_by_file(&mut all_lints, lints);
+
             let spinner_message = if is_success {
                 format!("{} {}", linter.name, style("success!").green())
             } else {
                 format!("{} {}", linter.name, style("failure").red())
             };
-            spinner.finish_with_message(spinner_message);
+
+            if !log_enabled!(log::Level::Debug) {
+                spinner.unwrap().finish_with_message(spinner_message);
+            }
             Ok(())
         });
         thread_handles.push(handle);
     }
 
-    spinners.join_and_clear()?;
+    spinners.join()?;
     for handle in thread_handles {
         handle.join().unwrap()?;
     }
